OC.L10N.register(
    "files",
    {
    "File could not be found" : "No fue posible encontrar el archivo",
    "Move or copy" : "Mover o copiar",
    "Download" : "Descargar",
    "Delete" : "Borrar",
    "Tags" : "Etiquetas",
    "Show list view" : "Mostrar vista de lista",
    "Show grid view" : "Mostrar vista de cuadrícula",
    "Home" : "Inicio",
    "Close" : "Cerrar",
    "Could not create folder \"{dir}\"" : "No fue posible crear la carpeta \"{dir}\"",
    "This will stop your current uploads." : "Se detendrán las cargas en curso",
    "Upload cancelled." : "Carga cancelada.",
    "Processing files …" : "Procesando archivos ...",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "No fue posible cargar {filename} ya que es una carpeta o tiene un tamaño de 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "No tienes suficiente espacio disponible, Estás cargando {size1} pero sólo cuentas con {size2} disponible",
    "Target folder \"{dir}\" does not exist any more" : "La carpeta destino \"{dir}\" ya no existe",
    "Not enough free space" : "No cuentas con suficiente espacio libre",
    "An unknown error has occurred" : "Ha ocurrido un error desconocido",
    "File could not be uploaded" : "No se ha podido subir el archivo",
    "Uploading …" : "Cargando...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "No es posible cargar este archivo",
    "Target folder does not exist any more" : "La carpeta destino ya no existe",
    "Operation is blocked by access control" : "Esta operación está bloqueada por el control de accesos",
    "Error when assembling chunks, status code {status}" : "Se presentó un error al ensamblar los bloques, código de estatus {status}",
    "Actions" : "Acciones",
    "Rename" : "Renombrar",
    "Move" : "Mover",
    "Copy" : "Copiar",
    "Choose target folder" : "Elegir carpeta destino",
    "Edit locally" : "Editar localmente",
    "Open" : "Abrir",
    "Delete file" : "Borrar archivo",
    "Delete folder" : "Borrar carpeta",
    "Disconnect storage" : "Desconectar almacenamiento",
    "Leave this share" : "Dejar este recurso compartido",
    "Could not load info for file \"{file}\"" : "No fue posible cargar información para el archivo \"{file}\"",
    "Files" : "Archivos",
    "Details" : "Detalles",
    "Please select tag(s) to add to the selection" : "Seleccione la(s) etiqueta(s) para añadir a la selección",
    "Apply tag(s) to selection" : "Aplicar etiqueta(s) a selección",
    "Select directory \"{dirName}\"" : "Seleccione carpeta \"{dirName}\"",
    "Select file \"{fileName}\"" : "Seleccione archivo \"{fileName}\"",
    "Pending" : "Pendiente",
    "Unable to determine date" : "No fue posible determinar la fecha",
    "This operation is forbidden" : "Esta operación está prohibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Esta carpeta no está disponible, por favor verfica las bitácoras o contacta al administrador",
    "Storage is temporarily not available" : "El almacenamiento no está disponible temporalmente ",
    "Could not move \"{file}\", target exists" : "No fue posible mover \"{file}\", el destino ya existe",
    "Could not move \"{file}\"" : "No fue posible mover \"{file}\"",
    "copy" : "copiar",
    "Could not copy \"{file}\", target exists" : "No se pudo copiar \"{file}\", el destino ya existe",
    "Could not copy \"{file}\"" : "No se pudo copiar \"{file}\"",
    "Copied {origin} inside {destination}" : "{origin} fue copiado dentro de {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} y otros {nbfiles} archivos fueron copiados dentro de {destination}",
    "Failed to redirect to client" : "Fallo al redirigir al cliente",
    "{newName} already exists" : "{newName} ya existe",
    "Could not rename \"{fileName}\", it does not exist any more" : "No fue posible renombrar \"{fileName}\", ya no existe",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nombre \"{targetName}\" ya está en uso en la carpeta \"{dir}\". Por favor elege un nombre diferete. ",
    "Could not rename \"{fileName}\"" : "No fue posible renombrar \"{fileName}\"",
    "Could not create file \"{file}\"" : "No fue posible crear el archivo \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "No fue posible crear el archivo\"{file}\" porque ya existe",
    "Could not create folder \"{dir}\" because it already exists" : "No fue posible crear la carpeta \"{dir}\" porque ya existe",
    "Could not fetch file details \"{file}\"" : "No se pudo recuperar detalles de archivo \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Se presentó un error al borrar el archivo \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "No se encontraron resultados en otras carpetas para  {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Ingrese al menos dos caracteres para buscar en otras carpetas",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetas","%n carpetas"],
    "_%n file_::_%n files_" : ["%n archivo","%n archivos","%n archivos"],
    "{dirs} and {files}" : "{dirs} y {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluyendo %n oculto","incluyendo %n ocultos","incluyendo %n ocultos"],
    "You do not have permission to upload or create files here" : "No tiene permiso para crear o cargar archivos aquí",
    "_Uploading %n file_::_Uploading %n files_" : ["Subiendo %n archivo","Cargando %n archivos","Cargando %n archivos"],
    "New" : "Nuevo",
    "New file/folder menu" : "Menú de carpeta/archivo nuevo",
    "Select file range" : "Seleccione rango de archivos",
    "{used}%" : "{used}%",
    "{used} of {quota} used" : "{used} de {quota} usados",
    "{used} used" : "{used} usados",
    "\"{name}\" is an invalid file name." : "\"{name}\" es un nombre de archivo inválido. ",
    "File name cannot be empty." : "El nombre de archivo no puede estar vacío.",
    "\"/\" is not allowed inside a file name." : "No se permite el uso del caracter \"/\" en el nombre del archivo.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" es un tipo de archivo no permitido",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "El espacio de {owner} está lleno. ¡Los archivos ya no se pueden actualizar o sincronizar!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "¡La carpeta de grupo  \"{mountPoint}\" está llena, los archivos ya no pueden ser actualizados o sincronizados!.",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "¡El almacenamiento externo  \"{mountPoint}\" está lleno, los archivos ya no pueden ser actualizados o sincronizados!.",
    "Your storage is full, files cannot be updated or synced anymore!" : "Tu almacenamiento está lleno. ¡No se puede actualizar o sincronizar ningún archivo más!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "El almacenamiento de {owner} está casi lleno ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "La carpeta de grupo \"{mountPoint}\" está casi llena ({usedSpacePercent}%)",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "El almacenamiento externo \"{mountPoint}\" está casi lleno ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Tu almacenamiento está casi lleno ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["coincide \"{filter}\"","coinciden \"{filter}\"","coinciden \"{filter}\""],
    "View in folder" : "Ver en la carpeta",
    "Direct link was copied (only works for users who have access to this file/folder)" : "Copiar enlace directo (solo funciona para usuarios que tienen acceso a este archivo/carpeta)",
    "Path" : "Ruta",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes","%n bytes"],
    "Favorited" : "Marcado como favorito",
    "Favorite" : "Favorito",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar liga directa (sólo funciona para usuarios que tienen acceso a este archivo/carpeta)",
    "New folder" : "Carpeta nueva",
    "Create new folder" : "Crear nueva carpeta",
    "Upload file" : "Cargar archivo",
    "Recent" : "Reciente",
    "Not favorited" : "No es un favorito",
    "Remove from favorites" : "Eliminar de favoritos",
    "Add to favorites" : "Agregar a favoritos",
    "An error occurred while trying to update the tags" : "Se presentó un error al intentar actualizar la etiqueta",
    "Added to favorites" : "Agregado a los favoritos",
    "Removed from favorites" : "Eliminado de los favoritos",
    "You added {file} to your favorites" : "Agregaste {file} a tus favoritos",
    "You removed {file} from your favorites" : "Eliminaste {file} de tus favoritos",
    "Favorites" : "Favoritos",
    "File changes" : "Cambios al archivo",
    "Created by {user}" : "Creado por {user}",
    "Changed by {user}" : "Cambiado por {user}",
    "Deleted by {user}" : "Borrado por {user}",
    "Restored by {user}" : "Restaurado por {user}",
    "Renamed by {user}" : "Renombrado por {user}",
    "Moved by {user}" : "Movido por {user}",
    "\"remote user\"" : "\"usuario remoto\"",
    "You created {file}" : "Creaste {file}",
    "You created an encrypted file in {file}" : "Creaste un archivo encriptado en {file}",
    "{user} created {file}" : "{user} creó {file}",
    "{user} created an encrypted file in {file}" : "{user} creó un archivo encriptado en {file}",
    "{file} was created in a public folder" : "{file} fue creado en una carpeta pública",
    "You changed {file}" : "Cambiaste {file}",
    "You changed an encrypted file in {file}" : "Cambiaste un archivo encriptado en {file}",
    "{user} changed {file}" : "{user} cambió {file}",
    "{user} changed an encrypted file in {file}" : "{user} cambió un archivo encriptado en {file}",
    "You deleted {file}" : "Borraste {file}",
    "You deleted an encrypted file in {file}" : "Borraste un archivo encriptado en {file}",
    "{user} deleted {file}" : "{user} borró {file}",
    "{user} deleted an encrypted file in {file}" : "{user} borró un archivo encriptado en {file}",
    "You restored {file}" : "Restauraste {file}",
    "{user} restored {file}" : "{user} restauró {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Has renombrado {oldfile} (oculto) a {newfile} (oculto)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Has renombrado {oldfile} (oculto) a {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Has renombrado {oldfile} a {newfile} (oculto)",
    "You renamed {oldfile} to {newfile}" : "Renombraste {oldfile} como {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} renombró {oldfile} (oculto) a {newfile} (oculto)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} renombró {oldfile} (oculto) a {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} renombró {oldfile} a {newfile} (oculto)",
    "{user} renamed {oldfile} to {newfile}" : "{user} renombró {oldfile} como {newfile}",
    "You moved {oldfile} to {newfile}" : "Moviste {oldfile} a {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} movió {oldfile} a {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Un archivo ha sido agregado o eliminado de tus <strong>favoritos</strong>",
    "A file or folder has been <strong>changed</strong>" : "Un archivo o carpeta ha sido <strong>cambiado</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Un archivo o carpeta favorito ha sido <strong>cambiado</strong>",
    "Upload (max. %s)" : "Cargar (max. %s)",
    "Accept" : "Aceptar",
    "Reject" : "Rechazar",
    "Incoming ownership transfer from {user}" : "Solicitud de transferencia de propiedad entrante de {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "¿Deseas aceptar {path}?\n\nNota: El proceso de transferencia tras aceptar podría tardar hasta 1 hora.",
    "Ownership transfer failed" : "Fallo al transferir la propiedad",
    "Your ownership transfer of {path} to {user} failed." : "Ha fallado tu transferencia de propiedad de {path} a {user}.",
    "The ownership transfer of {path} from {user} failed." : "Ha fallado la transferencia de propiedad de {path} desde {user}.",
    "Ownership transfer done" : "Transferencia de propiedad realizada",
    "Your ownership transfer of {path} to {user} has completed." : "Se ha completado su transferencia de propiedad de {path} a {user}.",
    "The ownership transfer of {path} from {user} has completed." : "Se ha completado la transferencia de propiedad de {path} a {user}.",
    "in %s" : "en %s",
    "File Management" : "Administración de Archivos",
    "You don’t have permission to upload or create files here" : "No cuentas con los permisos para cargar o crear archivos aquí",
    "Folder name" : "Nombre de la carpeta",
    "Name cannot be empty" : "El nombre no puede estar en blanco",
    "File not found" : "Archivo no encontrado",
    "Storage informations" : "Informaciones de almacenamiento",
    "{usedQuotaByte} used" : "{usedQuotaByte} utilizados",
    "{relative}% used" : "{relative}% utilizado",
    "Could not refresh storage stats" : "No fue posible actualizar las estadísticas de almacenamiento",
    "Your storage is full, files can not be updated or synced anymore!" : "Tu espacio está lleno. ¡Los archivos ya no se pueden actualizar o sincronizar!",
    "Transfer ownership of a file or folder" : "Transferir la propiedad de un archivo o carpeta",
    "Choose file or folder to transfer" : "Elegir archivo o carpeta para transferir",
    "Change" : "Cambiar",
    "New owner" : "Nuevo propietario",
    "Choose a file or folder to transfer" : "Elegir archivo o carpeta para transferir",
    "Transfer" : "Transferir",
    "Transfer {path} to {userid}" : "Transferir {path} a {userid}",
    "Invalid path selected" : "Ruta seleccionada no válida.",
    "Unknown error" : "Se presentó un error desconocido",
    "Ownership transfer request sent" : "Enviada la solicitud de transferencia de propiedad",
    "Cannot transfer ownership of a file or folder you do not own" : "No puedes transferir la propiedad de un archivo o directorio del cual no eres propietario",
    "Add" : "Guardar",
    "No files in here" : "No hay archivos aquí",
    "Upload some content or sync with your devices!" : "¡Carga algún contenido o sincroniza con tus dispositivos!",
    "Go back" : "Regresar",
    "Shared by link" : "Compartido por liga",
    "Shared" : "Compartido",
    "Open the files app settings" : "Abrir la configuración de la app Archivos",
    "Files settings" : "Configuración de archivos",
    "Show hidden files" : "Mostrar archivos ocultos",
    "Crop image previews" : "Recortar la previsualización de las imágenes",
    "Additional settings" : "Configuraciones adicionales",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "Copiar al portapapeles",
    "Use this address to access your Files via WebDAV" : "Use esta dirección para acceder a tus archivos vía WebDAV",
    "Clipboard is not available" : "El portapapeles no está disponible",
    "Unable to change the favourite state of the file" : "No se ha podido cambiar el estado de favorito del fichero",
    "Error while loading the file data" : "Error al cargar los datos del archivo",
    "Pick a template for {name}" : "Elija una plantilla para {name}",
    "Create" : "Crear",
    "Create a new file with the selected template" : "Crear un nuevo archivo con la plantilla seleccionada",
    "Creating file" : "Creando el archivo",
    "Blank" : "Vacío",
    "Unable to create new file from template" : "No se ha podido crear un nuevo archivo desde la plantilla",
    "Delete permanently" : "Borrar permanentemente",
    "Templates" : "Plantillas",
    "Unable to initialize the templates directory" : "No se ha podido iniciar la carpeta de plantillas",
    "No favorites yet" : "Aún no hay favoritos",
    "Files and folders you mark as favorite will show up here" : "Los archivos y carpetas que marques como favoritos se mostrarán aquí. ",
    "All files" : "Todos los archivos",
    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
    "Select all" : "Seleccionar todo",
    "Upload too large" : "La carga es demasido grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que estás intentando cargar sobrepasan el tamaño máximo permitido para la carga de archivos en este servidor.",
    "Text file" : "Archivo de texto",
    "New text file.txt" : "Nuevo ArchivoDeTexto.txt",
    "You can only favorite a single file or folder at a time" : "Solo puedes marcar como favorito un solo archivo o carpeta cada vez",
    "Search users" : "Buscar usuarios",
    "Cancel" : "Cancelar",
    "Set up templates folder" : "Configura una carpeta para plantillas",
    "Toggle %1$s sublist" : "Alternar %1$s sublista",
    "Toggle grid view" : "Vista de cuadrícula",
    "Deleted files" : "Papelera",
    "Shares" : "Elementos compartidos",
    "Shared with others" : "Compartido con otros",
    "Shared with you" : "Compartido con usted",
    "Deleted shares" : "Recursos compartidos eliminados",
    "Pending shares" : "Recursos compartidos pendientes",
    "Choose" : "Seleccionar"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
